pub struct GetSessionStatusFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetSessionStatus.
Gets the current status of a session.
Implementations
Sourceimpl GetSessionStatusFluentBuilder
impl GetSessionStatusFluentBuilder
Sourcepub fn as_input(&self) -> &GetSessionStatusInputBuilder
pub fn as_input(&self) -> &GetSessionStatusInputBuilder
Access the GetSessionStatus as a reference.
Sourcepub async fn send(
self,
) -> Result<GetSessionStatusOutput, SdkError<GetSessionStatusError, HttpResponse>>
pub async fn send( self, ) -> Result<GetSessionStatusOutput, SdkError<GetSessionStatusError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetSessionStatusOutput, GetSessionStatusError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetSessionStatusOutput, GetSessionStatusError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn session_id(self, input: impl Into<String>) -> Self
pub fn session_id(self, input: impl Into<String>) -> Self
The session ID.
Sourcepub fn set_session_id(self, input: Option<String>) -> Self
pub fn set_session_id(self, input: Option<String>) -> Self
The session ID.
Sourcepub fn get_session_id(&self) -> &Option<String>
pub fn get_session_id(&self) -> &Option<String>
The session ID.